/* Replication of Fiva and Smith: Local Candidates and Voter Mobilization: Evidence from Historical Two-Round Elections in Norway */

*** these packages need to be installed
* ssc install binscatter
* ssc install sutex
* ssc install listtab

local path="C:\Users\a0910846\Dropbox\Runoff\FivaSmith_ES_Replication"
cd `path'
cap mkdir "`path'\tables"
cap mkdir "`path'\figures"
cap mkdir "`path'\figures\gph"
cap mkdir "`path'\dta\ComputingNoC"

********************************************************************************
******************** Data preparation ******************************************
********************************************************************************

run do\SMD_Candidate   /* preparation of candidate level data. SMD_Candidate_all.dta include all districts. SMD_Candidate.dta excludes one-municipality districts */ 
run do\SMD_Candidate_all_2   /* merging data from NSD, finding winner and runnerup, labeling */
run do\Panel    /* creating a panel data set at the municipal level */
run do\ComputingNOC 
run do\ENoC_District

********************************************************************************
************************* Analysis *********************************************
********************************************************************************

/* Table 1: Descriptive Statistics */
run do\Table1.do  

/* Table 2: Effect of Margin and Candidate Exit on Change in Turnout */
run do\Table2.do

/* Table 3: Effect of Local Candidate Exit on Change in Support for Party Bloc */
run do\Table3.do

/* Table 4: Example of Vote Movement Between Rounds: Nordland County 4th District, Nordre Salten, 1918 */
* nothing to replicate

/* Figure 1: Municipality-Level Electoral Participation */
run do\Figure1.do

/* Figure 2: Kernel Density Plot of Candidates' Municipality-Level Vote Shares */
run do\Figure2.do

/* Figure 3: Change in Turnout and First-Round Margin */
run do\Figure3.do

/* Descriptives first paragraph section 4 */
** In the first round, the median vote share of a candidate within his or her hometown is 38 percent; in contrast, the median vote share in other municipalities is 27 percent.
run do\MedianSupport.do

/* Table A.1: District Level Descriptive Statistics by Party */
run do\TableA1.do /* USING dta/SMD_Candidate_all2 giving party level descriptives */

/* Table A.2: How the Number of Local Candidates Change Across Rounds By Party Bloc */
do do\TableA2.do /* some simple stats for manual punching in latex table */ 

/* Table A.3: Effect of Candidate Exit on Change in Turnout: Sample Split by Hometown Candidate Status in the Second Round */
run do\TableA3.do

/* Table A.4: Effect of Candidate Exit on Change in Turnout: Sample Limited to Cases Where Bloc Participated in the Second Round */
run do\TableA4.do

/* Table A.5: Effect of Candidate Exit on Change in Fraction of Invalid Votes*/
run do\Invalid.do
run do\TableA5.do

/* Table A.6: Change in Electoral Support and Change in Hometown Match: Sample Limited to Cases Where Bloc Participated in the Second Round */
run do\TableA6.do

/* Figure A.1: Electoral Support for Front-Runner in First Round */
run do\FigureA1.do

/* Figure A.2: Municipality Share of District Electorate Size */
run do\FigureA2.do

/* Figure A.3: Electoral Coordination at the Party Level */
run do\FigureA3.do

/* Figure A.4: Electoral Coordination at the Bloc Level */
** delete "gr play RemoveNote"
run do\FigureA4.do

/* Figure A.5: Margin in First Round when a Second Round was Held */
run do\FigureA5.do
