use dta/SMD_Candidate_With_Zeros, clear

drop if OneMunicipalityDistrict==1

drop totalvotes

/* DROPPING ALL CASES WHERE A CAND NEVER RUN */

** v has up to four candidates
** s has up to three candidates, other parties max two candidates

foreach party in s {
drop if party=="`party'" & cand=="c4"
}

** these parties have max two cand ----  a fv h h_fv 

foreach party in a fv h h_fv {
drop if party=="`party'" & cand=="c3"
drop if party=="`party'" & cand=="c4"
}

** these parties have max one cand ----  kir l oth spr t v_a

foreach party in kir l oth spr t v_a {
drop if party=="`party'" & cand=="c2"
drop if party=="`party'" & cand=="c3"
drop if party=="`party'" & cand=="c4"
}


gen round_new=1
replace round_new=2 if round=="r2"
drop round
rename round_new round

/* COLLAPSING VOTES TO THE DISTRICT LEVEL */
collapse (sum) votes, by(year valgkrets cand party round)

gen running=0
replace running=1 if votes>0

egen totalvotes=sum(votes), by(year valgkrets round)
gen votesh=votes/totalvotes
egen maxvotesh=max(votesh), by(year valgkrets round)

egen rank=rank(votesh*(-1)), by(year valgkrets round)
replace rank=. if votesh==0
gen winner=0
replace winner=1 if rank==1 
gen runnerup=0
replace runnerup=1 if rank==2

gen seat=0 
replace seat=1 if (round==1 & winner==1 & votesh>0.5 & votesh!=.)
replace seat=1 if (round==2 & winner==1 & votesh==maxvotesh & votesh!=.)

egen round_in_play=max(seat), by(year valgkrets round)


/* DISTRICT LEVEL ENoC CALCULATION*/


foreach round in 1 2 {
preserve
keep if round==`round'
collapse (sum) votesh, by(year valgkrets rank)
drop if votesh==0
gen voteshSQ=votesh*votesh
keep voteshSQ year valgkrets rank

reshape wide voteshSQ, i(year valgkrets) j(rank) 

egen sumvoteshSQ=rowtotal(voteshSQ*)
gen VoteENoC=1/sumvoteshSQ

*hist VoteENoC, title(Effective No. of Candidates Round `round') subtitle(District Level) xtitle("") bfcolor(gs10) blcolor(gs6) graphregion(fcolor(white)) scheme(s1mono) start(1) xlabel(1(1)7) 
*graph save figures/ENoC`round'.gph, replace
sum VoteENoC
li valgkrets year if VoteENoC<1.2
restore
}

*cd figures
*graph combine ENoC1.gph ENoC2.gph, graphregion(fcolor(white)) scheme(s1mono) xcommon ycommon
*graph export ENoC.tif, replace
*graph export ENoC.eps, replace
*cd ..


/* DISCTRICT NoC CALCULATION*/  /* NEW RANK EXCLUDES SPREDTE WHICH NEVER HAS A CAND. RUNNING */
foreach round in 1 2 {
preserve
keep if round==`round'
drop if party=="spr" 
drop if votesh==0
egen newrank=rank(votesh*(-1)), by(year valgkrets)   
egen NoC=max(newrank), by(year valgkrets)

collapse NoC, by(year valgkrets)

*hist NoC, title(No. of Candidates Round `round') xtitle("") bfcolor(gs10) blcolor(gs6) graphregion(fcolor(white)) scheme(s1mono) start(1) xlabel(1(1)7) discrete
*graph save figures/NoC`round'.gph, replace
sum NoC, de
rename NoC NoC`round'
keep year valgkrets NoC
sort year valgkrets
save dta/NoC`round'.dta, replace   /* output for analysis.do */
restore
}


/*
cd figures
graph combine NoC1.gph NoC2.gph, graphregion(fcolor(white)) scheme(s1mono) xcommon 
graph export NoC.tif, replace
graph export NoC.eps, replace
cd ..

cd figures
graph combine NoC1.gph NoC2.gph ENoC1.gph ENoC2.gph, graphregion(fcolor(white)) scheme(s1mono) xcommon
graph export NoC_ENoC.tif, replace
graph export NoC_ENoC.eps, replace
cd ..

*/
