use dta\SMD_Candidate.dta, clear

egen test=sum(voteshare), by(knr year round)  /* verifying that voteshare is the local voteshare for candidate */
drop if test==0 /* round not in play */
drop if party=="spr" /* THESE ARE NOT ACTUAL CANDIDATES */

/* FIGURES FOR HOMETOWN BIAS  - DENSITY ver 2 */
cd figures\gph

twoway (kdensity voteshare if match==0 & round=="r1", lwidth(vthin)) (kdensity voteshare if match==1 & round=="r1", lwidth(vthick)), ///
title(First Round) xtitle(Share of Total Votes) ytitle(Density) legend(order(2 "Local" 1 "Non-Local" ) pos(7) ring(0) col(1)) yscale(range(0 3)) ///
plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(1)3, grid angle(0))
graph save Hometown_kdensity_r1.gph, replace

twoway (kdensity voteshare if match==0 & round=="r2", lwidth(vthin)) (kdensity voteshare if match==1 & round=="r2", lwidth(vthick)), ///
title(Second Round) xtitle(Share of Total Votes) ytitle(Density) legend(order(2 "Local" 1 "Non-Local" ) pos(7) ring(0) col(1)) ///
plotregion(lcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ytitle("") ysc(noline) ytick(none) ylabel(0(1)3, grid angle(0))
graph save Hometown_kdensity_r2.gph, replace

graph combine Hometown_kdensity_r1.gph Hometown_kdensity_r2.gph, title("") note("") graphregion(fcolor(white)) plotregion(ifcolor(red)) scheme(s1mono) xcommon ycommon 
graph export ../Figure2.tif, replace
graph export ../Figure2.eps, replace

cd ../../

*bysort match: sum voteshare if round=="r1", de
*bysort match: sum voteshare if round=="r2", de
*tab voteshare if match==0 & round=="r1"
