************************************************************************************************************
*** this file is identical to SMD_Descriptives_Party until /* COLLAPSING VOTES TO THE DISTRICT LEVEL */ ****
************************************************************************************************************

use dta/SMD_Candidate_With_Zeros, clear

drop totalvotes

/* DROPPING ALL CASES WHERE A CAND NEVER RUN */

** v has up to four candidates
** s has up to three candidates, other parties max two candidates

foreach party in s {
drop if party=="`party'" & cand=="c4"
}

** these parties have max two cand ----  a fv h h_fv 

foreach party in a fv h h_fv {
drop if party=="`party'" & cand=="c3"
drop if party=="`party'" & cand=="c4"
}

** these parties have max one cand ----  kir l oth spr t v_a

foreach party in kir l oth spr t v_a {
drop if party=="`party'" & cand=="c2"
drop if party=="`party'" & cand=="c3"
drop if party=="`party'" & cand=="c4"
}

replace votes=0 if votes==.

gen round_new=1
replace round_new=2 if round=="r2"
drop round
rename round_new round

*******************************************************************************************
******* IDENTICAL TO HERE   ***************************************************************
*******************************************************************************************

/* fixing a minor typo in name */
replace name="Landmark, M. Angell" if name=="Landmark, M Angell"

/* COLLAPSING VOTES TO THE DISTRICT LEVEL */
collapse (sum) votes, by(year valgkrets cand name party round)

gsort year valgkrets round -votes party 

egen partyvotes=sum(votes), by(year valgkrets party round)
egen totalvotes=sum(votes), by(year valgkrets round)

gen zz=1
replace zz=2 if totalvotes>0 & totalvotes!=. & round==2 
egen totalrounds=max(zz), by(year valgkrets)
drop zz

*******************************************************************************************
******* KEEPING only TOTAL ROUNDS==2   ****************************************************
*******************************************************************************************


drop if totalrounds==1 /* there is no room for electoral coordination with one round */

*******************************************************************************************
******* KEEPING THREE BLOCS OF POLITICAL PARTIES ******************************************
*******************************************************************************************

drop if name=="."

************ DROPPING ALL PARTIES THAT ARE NOT PART OF ONE OF THREE POLITICAL BLOCS *******
foreach party in kir l oth spr t {
drop if party=="`party'"
}

gen bloc=0
replace bloc=1 if party=="s"

replace bloc=2 if party=="v"
replace bloc=2 if party=="a"
replace bloc=2 if party=="v_a"

replace bloc=3 if party=="h"
replace bloc=3 if party=="fv"
replace bloc=3 if party=="h_fv"



gen count=1
drop if name=="" 


******************************************************************************************
******* CREATING RANK within party ****************************************
******************************************************************************************

gen competition=0
replace competition=1 if votes!=partyvotes & votes!=0 & round==1 /* the candidate do not get entire partyvote in first round*/
egen districtcompetition=max(competition), by(year valgkrets) /* at least competition for one party within district */
keep if districtcompetition==1 /* keeping only districts w. within party competition */

bysort round: sum districtcompetition

egen partyrank=rank(-votes), by(year valgkrets party round)  /* candidates rank within party */

gsort year valgkrets round party partyrank 

******************************************************************************************
******* NUMBER OF ROUNDS CAND. IS COMPETING **********************************************
******************************************************************************************

egen cand_rounds=sum(count), by(year valgkrets name)

egen partycompetition=max(competition), by(year valgkrets party) /* partycompetition =1 if competition in first or second round */
keep if partycompetition==1 

bysort partyrank: tab cand_rounds if round==1

twoway histogram cand_rounds if round==1, discrete by(partyrank) freq xlabel(1(1)2) xtitle(Number of Rounds Candidates Are Running) title(First Round Rank) graphregion(fcolor(white)) scheme(s1mono) 
*gr play RemoveNote
graph export figures\FigureA3.tif, replace
graph export figures\FigureA3.eps, replace
