use dta\SMD_Candidate.dta, clear   /* INCLUDED IN dta/SMD_Candidate ,  ARE ALL DISTRICTS, EXCEPT ONE-MUNICIPALITY DISTRICTS, I.E. THOSE WITHOUT HOMETOWNS */

gen round_new=1
replace round_new=2 if round=="r2"
drop round
rename round_new round

/* MERGING ELIGIBLE AND UNION DATA FROM NSD */

sort knr year round party cand
merge knr year using dta\eligible1909
drop _merge

sort knr year round party cand
merge knr year using dta\eligible1912, update
drop _merge

sort knr year round party cand
merge knr year using dta\eligible1915, update
drop _merge

sort knr year round party cand
merge knr year using dta\eligible1918, update
drop _merge

drop if OneMunicipalityDistrict==. /* THESE ARE ONE-MUNICIPALITY DISTRICTS, I.E. NO HOMETOWNS HERE */

/* INCLUDING FOLKETELLINGEN 1910 */

sort knr 
merge knr using dta\folketellingen1910.dta
tab _merge

rename v5 pop_male_1910
rename v6 pop_female_1910
rename v7 pop_1910

drop v1-v4
drop v8-v182
drop _merge

/* KEY VARIABLES - AT THE MUNICIP LEVEL  */
drop totalvotes voteshare

egen totalvotes_mun=sum(votes), by(year knr round)
egen totalvotes_dis=sum(votes), by(year valgkrets round)

egen votes_dis=sum(votes), by(year valgkrets round party cand)

gen turnout_mun=totalvotes_mun/eligible
gen voteshare_mun=votes/totalvotes_mun

gen voteshare_dis=votes_dis/totalvotes_dis
egen maxvotesh=max(voteshare_dis), by(year valgkrets round)


/* FINDING WINNER  and RUNNER-UP AT THE DISTRICT LEVEL  */

egen rank=rank(voteshare_dis*(-1)), by(year knr round)
gen winner=0
replace winner=1 if rank==1 
gen runnerup=0
replace runnerup=1 if rank==2

gen diff_to_max=maxvotesh-voteshare_dis
replace diff_to_max=. if diff_to_max==0
egen margin=min(diff_to_max), by(year valgkrets round)



/* MATCH WITH HOMETOWN AND BLOC */

gen match_s=0
replace match_s=1 if party=="s" & match==1 & match!=.

gen match_h_fv=0
replace match_h_fv=1 if party=="h" & match==1 & match!=.
replace match_h_fv=1 if party=="fv" & match==1 & match!=.
replace match_h_fv=1 if party=="h_fv" & match==1 & match!=.

gen match_v_a=0
replace match_v_a=1 if party=="v" & match==1 & match!=.
replace match_v_a=1 if party=="a" & match==1 & match!=.
replace match_v_a=1 if party=="v_a" & match==1 & match!=.

gen match_oth=0
replace match_oth=1 if party=="kir" & match==1 & match!=.
replace match_oth=1 if party=="l" & match==1 & match!=.
replace match_oth=1 if party=="oth" & match==1 & match!=.
replace match_oth=1 if party=="t" & match==1 & match!=.


/* VOTESHARE FOR BLOC */

gen bloc=.
replace bloc=0 if (party=="kir" | party=="l" | party=="oth" | party=="t")
replace bloc=1 if party=="s"
replace bloc=2 if (party=="h"| party=="h_fv"| party=="fv")
replace bloc=3 if (party=="v"| party=="v_a"|  party=="a")

egen totalvotes_mun_bloc=sum(votes), by(year knr round bloc)

gen totalvotes_mun_oth=0
*replace totalvotes_mun_oth=totalvotes_mun_bloc if (party=="kir" | party=="l" | party=="oth" | party=="t")
replace totalvotes_mun_oth=totalvotes_mun_bloc if (party=="kir" | party=="l" | party=="oth" | party=="t" | party=="spr")  /* INCLUDING SPR IN OTH */

gen totalvotes_mun_s=0
replace totalvotes_mun_s=totalvotes_mun_bloc if party=="s"

gen totalvotes_mun_h_fv=0
replace totalvotes_mun_h_fv=totalvotes_mun_bloc if (party=="h"| party=="h_fv"| party=="fv")

gen totalvotes_mun_v_a=0
replace totalvotes_mun_v_a=totalvotes_mun_bloc if (party=="v"| party=="v_a"|  party=="a")

foreach bloc in oth s h_fv v_a {
egen totalvotes_dis_`bloc'=sum(totalvotes_mun_`bloc'),  by(year valgkrets round bloc)
gen running_`bloc'=0
replace running_`bloc'=1 if totalvotes_dis_`bloc'>0 & totalvotes_dis_`bloc'!=.
}

/* COLLAPSING */

drop if round==.
drop if round==2 & totalvotes_dis==0
collapse valgkrets turnout_mun margin avd med eligible city pop_* (sum) match* (max) totalvotes* running*, by(year knr round)

/* CHECKING THAT ELIGIBLE1OVERALL MAKES SENSE */

gen checking=eligible/pop_1910
li year knr valgkrets round turnout_mun totalvotes_mun elig pop* checking if turnout_mun<0.1

sum totalvotes_mun_oth if round==2

gen time=.
replace time=1 if year==1909 & round==1
replace time=2 if year==1909 & round==2
replace time=3 if year==1912 & round==1
replace time=4 if year==1912 & round==2
replace time=5 if year==1915 & round==1
replace time=6 if year==1915 & round==2
replace time=7 if year==1918 & round==1
replace time=8 if year==1918 & round==2

xtset knr time

foreach var in margin turnout totalvotes_mun totalvotes_mun_oth totalvotes_mun_s totalvotes_mun_h_fv totalvotes_mun_v_a{
gen lag_`var'=l.`var'
gen fut_`var'=f.`var'
}

gen lag_margin2=lag_margin*lag_margin

*gen totalvotes_mun_spr=totalvotes_mun-(totalvotes_mun_oth+totalvotes_mun_s+totalvotes_mun_h_fv+totalvotes_mun_v_a)
gen totalvotes_mun_abstain=eligible1overall-totalvotes_mun


foreach bloc in s h_fv v_a oth {
gen voteshare_`bloc'=totalvotes_mun_`bloc'/totalvotes_mun
gen change_running_`bloc'=running_`bloc'-l.running_`bloc'
}

foreach bloc in s h_fv v_a oth {
gen change_voteshare_`bloc'=voteshare_`bloc'-l.voteshare_`bloc'
}

foreach bloc in s h_fv v_a oth abstain{
gen voteshareELIG_`bloc'=totalvotes_mun_`bloc'/eligible1overall
}

foreach bloc in s h_fv v_a oth abstain{
gen change_voteshareELIG_`bloc'=voteshareELIG_`bloc'-l.voteshareELIG_`bloc'
}

foreach bloc in s h_fv v_a oth abstain{
gen change_totalvotes_mun_`bloc'=totalvotes_mun_`bloc'-l.totalvotes_mun_`bloc'
}

gen change_turnout=turnout-l.turnout
gen change_match=match-l.match

foreach bloc in oth s h_fv v_a {
gen change_match_`bloc'=match_`bloc'-l.match_`bloc'
}

gen union=avd>0


gen change_matchXlag_margin=change_match*lag_margin
gen change_matchXunion=change_match*union
gen change_matchXlag_marginXunion=change_match*lag_margin*union
gen lag_marginXunion=lag_margin*union

tab year, gen(d_year)

rename d_year1 d_1909
rename d_year2 d_1912
rename d_year3 d_1915
rename d_year4 d_1918

drop d_1909

gen valgkretsXyear=valgkrets*year
tab valgkretsXyear, g(d_valgkretsXyear)

/* LABELING */

*label var maxvotesh "District Largest Fraction of Votes Obtained"
label var margin "District Difference in Voteshare Between Winner and Runner-up"
label var turnout_mun "Municipal Electoral Participation"

sort valgkrets year
merge valgkrets year using dta/InSample2  /* VARIABLE =1 IF TWO ROUND */

save dta\panel, replace
