use dta/SMD_Candidate_With_Zeros, clear

drop totalvotes

/* DROPPING ALL CASES WHERE A CAND NEVER RUN */

** v has up to four candidates
** s has up to three candidates, other parties max two candidates

foreach party in s {
drop if party=="`party'" & cand=="c4"
}

** these parties have max two cand ----  a fv h h_fv 

foreach party in a fv h h_fv {
drop if party=="`party'" & cand=="c3"
drop if party=="`party'" & cand=="c4"
}

** these parties have max one cand ----  kir l oth spr t v_a

foreach party in kir l oth spr t v_a {
drop if party=="`party'" & cand=="c2"
drop if party=="`party'" & cand=="c3"
drop if party=="`party'" & cand=="c4"
}

replace votes=0 if votes==.

gen round_new=1
replace round_new=2 if round=="r2"
drop round
rename round_new round

/* COLLAPSING VOTES TO THE DISTRICT LEVEL */
collapse (sum) votes, by(year valgkrets cand party round)

gen running=0
replace running=1 if votes>0

egen totalvotes=sum(votes), by(year valgkrets round)
gen votesh=votes/totalvotes
egen maxvotesh=max(votesh), by(year valgkrets round)

egen rank=rank(votesh*(-1)), by(year valgkrets round)
gen winner=0
replace winner=1 if rank==1 
gen runnerup=0
replace runnerup=1 if rank==2

gen seat=0 
replace seat=1 if (round==1 & winner==1 & votesh>0.5 & votesh!=.)
replace seat=1 if (round==2 & winner==1 & votesh==maxvotesh & votesh!=.)

egen round_in_play=max(seat), by(year valgkrets round)

/* AGGREGATING TO PARTIES */

collapse (sum) votesh running winner runnerup seat round_in_play, by(year party valgkrets round)

drop if round_in_play==0 & round==2

save dta/parties_competing, replace

/* COLLAPSING VOTES TO THE PARTY - year LEVEL - for calculating overall ENOP */
preserve
replace votesh=. if round==2   /* ONLY INTERESTED IN VOTES IN FIRST ROUND */
collapse votesh (sum) seat, by(year party)
save dta/yearly_election_results, replace
restore

/* COLLAPSING VOTES TO THE PARTY LEVEL */

collapse votesh running (sum) seat, by(party round)

replace running=0 if party=="spr"  /* THESE ARE SMALL NUMBER OF VOTES FOR VARIOUS CANDIDATES */

reshape wide votesh running seat, i(party) j(round)

gen bloc=4
replace bloc=1 if party=="s"
replace bloc=2 if (party=="v"| party=="v_a"|  party=="a")
replace bloc=3 if (party=="h"| party=="h_fv"| party=="fv")

sort bloc party

*ed

generate str var6 = "Labor Party (S)" in 1
replace var6 = "Worker Democrats (A)" in 2
replace var6 = "Liberals (V)" in 3
replace var6 = "Coalition V / A" in 4
replace var6 = "Liberal Left (FV)" in 5
replace var6 = "Conservatives (H)" in 6
replace var6 = "Coalition FV / H" in 7
replace var6 = "Church Party (KIR)" in 8
replace var6 = "Farmers' Assoc. (L)" in 9
replace var6 = "Various" in 10
replace var6 = "Spredte" in 11
replace var6 = "Avholdspartiet (T)" in 12

format running1 running2 votesh1 votesh2 %9.3f

listtab var6 running1 votesh1 seat1 running2 votesh2 seat2 using tables\TableA1.tex, replace type rstyle(tabular) ///
head("\begin{table}[htbp] \centering \caption{Descriptive Statistics by Party List \label{DescrStatsByParty}} \begin{tabular}{lcccccc}" `"\hline \textit{Party List}&\textit{Candidates}&\textit{Votesh.}&\textit{Seats}&\textit{Candidates}&\textit{Votesh.}&\textit{Seats}\\ \hline"') ///
foot("\hline" "\end{tabular}" "\newline" "\textit{Note: Descriptives based on election data from 1909-1918. N=495.}"  "\end{table}")



